# Micro wave recommendations

| Mode | Micro wave | Grill | Example |
| -------- | -------- | -|------- |
| ![img](images/low.png) Low     |120W |    | Soften ice cream     |
| ![img](images/defrost.png)  Defrost     | 230W|     | Soup stew, soften butter or defrost     |
| ![img](images/mode1.png) Med     | 400W |      | Stew, fish     |
| ![img](images/mode2.png) Med++     | 500W |     | Rice, fish, chicken, ground meat     |
| ![img](images/mode3.png) High     | 700W |     | Reheat, milk, boil water, vegetables, beverage     |
| ![img](images/grill.png) Grill     |  | 100%      | Sausage, lamb, kebabs, seafood, steak     |
| Combi 1     | 20%| 80%       | Chicken pieces, chicken breasts, pork chops     |
| Combi 2     | 30%| 70%       | Whole chicken     |
| Combi 3     | 40%| 60%       | Baken bread, Slice food     |
